import request from '@/utils/request'
const ProcessGroupEnum = {
    /**
     * 单据类型 AE
     */
    AE:'1',

    /**
     * 单据类型 MC
     */
    MC: '2',

    /**
     * 单据类型 DC
     */
    DC: '3'
}
/**
 * Ae流程实例 - 分页查询
 * @param query
 * @returns {*}
 */
export function queryInstanceListAeByPage(query) {
    return request({
        url: '/sysprocessinstance/page/ae',
        method: 'get',
        params: query
    })
}
/**
 * 查询流程列表
 * @param params
 * @returns {AxiosPromise}
 */
export function queryInstanceByPage(params) {
    return request({
        url: `/process/instance/list`,
        method: 'get',
        params
    })
}
/**
 * 流程实例 - 获取详情
 * @param instanceId
 * @returns {*}
 */
export function getProcessNodeByInstanceId(instanceId) {
    return request({
        url: `/sysprocessbasic/getProcessNode/${instanceId}`,
        method: 'get'
    })
}
/**
* 管理员审批
* @param query
* @returns {*}
*/
export function approveByAdmin(query) {
    // 需要根据传回的url判断是哪个接口
    const { url } = query
    if (query.processGroup === ProcessGroupEnum.MC) {
        return MCService({
            url: url,
            method: 'post',
            params: query
        })
    } else if (query.processGroup === ProcessGroupEnum.DC) {
        return DCService({
            url: url,
            method: 'post',
            params: query
        })
    } else {
        return request({
            url: url,
            method: 'post',
            params: query
        })
    }
}
export function getProcessInstanceStatus(instanceId) {
    return request({
        url: `/sysprocessbasic/getProcessInstanceStatus/${instanceId}`,
        method: 'get'
    })
}
// 1. 工具点检_根据流程实例id查找流程实例审批详情
export function getToolProcessDetail(businessId) {
    return request({
      url: '/toolInspectMonitor/getDetail/'+businessId,
      method: 'get',
    })
  }
  // 2. 工具点检_工具点检流程审批
  export function toolProcessGxApproval(approve) {
    return request({
      url: '/toolInspectMonitor/processToolApproval',
      method: 'post',
      data: approve,
      headers: {
        'Content-Type': 'application/json;charset=UTF-8' // 接口修改传参类型
      }
    })
  }
  // 1. 生产辅材_根据流程实例id查找流程实例审批详情
export function getMateriaProcessDetail(businessId) {
    return request({
      url: '/aeauxiliarymaterial/getDetail/'+businessId,
      method: 'get',
    })
  }
  // 1. 设备标定_根据流程实例id查找流程实例审批详情
export function getSignProcessDetail(businessId) {
    return request({
      url: '/qc/equipment/sign/getDetail/'+businessId,
      method: 'get',
    })
  }
  // 1. 设备TPM_根据流程实例id查找流程实例审批详情
export function getTpmProcessDetail(businessId) {
    return request({
      url: '/qc/equipment/tpm/getDetail/'+businessId,
      method: 'get',
    })
  }